Index: src/gpu/gl/GrGLCaps.cpp |
diff --git a/src/gpu/gl/GrGLCaps.cpp b/src/gpu/gl/GrGLCaps.cpp |
index 5a1a5b459baa5cc604fd24f6283b26c4d6755a9b..ea02d21c90e46332c215e68da2388535938049f4 100644 |
--- a/src/gpu/gl/GrGLCaps.cpp |
+++ b/src/gpu/gl/GrGLCaps.cpp |
@@ -972,8 +972,9 @@ void GrGLCaps::initBlendEqationSupport(const GrGLContextInfo& ctxInfo) { |
SkASSERT(this->advancedBlendEquationSupport()); |
- if (kNVIDIA_GrGLDriver == ctxInfo.driver()) { |
- // Blacklist color-dodge and color-burn on NVIDIA until the fix is released. |
+ if (kNVIDIA_GrGLDriver == ctxInfo.driver() && |
+ ctxInfo.driverVersion() < GR_GL_DRIVER_VER(355,00)) { |
+ // Blacklist color-dodge and color-burn on pre-355.00 NVIDIA. |
fAdvBlendEqBlacklist |= (1 << kColorDodge_GrBlendEquation) | |
(1 << kColorBurn_GrBlendEquation); |
} |